@@ -80,7 +80,6 @@ describe 'nova::api' do
           :metadata_listen_port         => 8875,
           :osapi_compute_listen_port    => 8874,
           :use_forwarded_for            => false,
-          :ratelimits                   => '(GET, "*", .*, 100, MINUTE);(POST, "*", .*, 200, MINUTE)',
           :osapi_compute_workers        => 1,
           :metadata_workers             => 2,
           :enable_proxy_headers_parsing => true,
@@ -144,7 +143,7 @@ describe 'nova::api' do
       end
       it { is_expected.to contain_openstacklib__service_validation('nova-api').with(
         :command   => 'nova --os-auth-url http://127.0.0.1:5000/ --os-project-name services --os-username novae --os-password passw0rd flavor-list',
-        :subscribe => 'Service[nova-api]',
+        :subscribe => 'Anchor[nova::service::end]',
       )}
 
     end
@@ -158,7 +157,7 @@ describe 'nova::api' do
       end
       it { is_expected.to contain_openstacklib__service_validation('nova-api').with(
         :command   => 'my-script',
-        :subscribe => 'Service[nova-api]',
+        :subscribe => 'Anchor[nova::service::end]',
       )}
     end
 
@@ -320,7 +319,7 @@ describe 'nova::api' do
 
   shared_examples 'nova-api on Debian' do
     context 'with default parameters' do
-      it { is_expected.to contain_service('nova-api- metadata').with(
+      it { is_expected.to contain_service('nova-api-metadata').with(
         :name      => 'nova-api-metadata',
         :ensure    => 'running',
         :hasstatus => true,
@@ -349,7 +348,7 @@ describe 'nova::api' do
         end
       end
       it_behaves_like 'nova-api'
-      if facts[:os_package_type] == 'debian'
+      if facts[:operatingsystem] == 'Debian'
         it_behaves_like 'nova-api on Debian'
       end
     end
